#!/usr/bin/perl -w
#
# Sensor for gathering RPC performance data for Zabbix via
# nfsstat command.
# Copyright (c) 2008 Jakov Sosic
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
#
# Changes and Modifications
# * Thu May 15 03:40:39 CEST 2008       
#       - script created
#

use strict;

# zabbix path
my $zabbix_sender="/usr/bin/zabbix_sender";
my $zabbix_confd="/etc/zabbix/zabbix_agentd.conf";
my $zabbix_send_command="$zabbix_sender -c $zabbix_confd";

# signal handling
$SIG{'ALRM'} = sub {
	local $SIG{TERM} = 'IGNORE';
	kill TERM => -$$;
	print "0\n";
};

local $SIG{TERM} = sub {
	local $SIG{TERM} = 'IGNORE';
	kill TERM => -$$;
	print "0\n";
};

# get nfs statistics
alarm 3;
my $nfsstat = '/usr/sbin/nfsstat';
my @output = qx($nfsstat -r);

# if something brakes, exit
if ( $#output < 1 ) { print"0\n"; exit(-1); }

# store information to arrays
my $one_line;
my @keys;
my @values;
foreach $one_line (@output) {
   if ( $one_line =~ /calls/  ) { @keys = split (/[\s]+/,$one_line); }
   if ( $one_line =~ /[0-9]+/ ) { @values = split (/[\s]+/,$one_line); }
}

# send information to Zabbix server
alarm 3;
my $count=0;
while ( $keys[$count] ){
   #print "$keys[$count] $values[$count]\n";
   if ( qx($zabbix_send_command -k rpc.$keys[$count] -o $values[$count]) =~ /failed:\ 1/ ) { print"0\n"; exit(-1);}
   $count++;
}

print "1\n";
exit(0);
# EOF
